from aenum import IntEnum


'''
@ref https://developer.mozilla.org/en-US/docs/Web/HTTP/Status
'''
class HttpStatus(IntEnum):

    # Successful responses (200 – 299)
    Ok_200 = 200
    Created_201 = 201
    Accepted_202 = 202
    No_Content_204 = 204
    Reset_Content_205 = 205
    Partial_Content_206 = 206

    # Client error responses (400 – 499)
    Bad_Request_400 = 400
    Unauthorized_401 = 401
    Forbidden_403 = 403
    Not_Found_404 = 404
    Method_Not_Allowed_405 = 405
    Not_Acceptable_406 = 406
    Conflict_409 = 409
    Unprocessable_Entity_422 = 422
    Upgrade_Required_426 = 426

    # Server error responses (500 – 599)
    Internal_Server_Error_500 = 500
    Not_Implemented_501 = 501
    Bad_Gateway_502 = 502
    Service_Unavailable_503 = 503
    Insufficient_Storage_507 = 507

    Network_Authentication_Required_511 = 511



from typing import Final

class GaiaDefaultTutorialSite:
    class InitTutorial1:
        UUID: Final[str] = "c42edc7f-f382-40c6-b042-68858daa8ec3"
    class InitTutorial2:
        UUID: Final[str] = "26630f2f-ab60-417f-bae9-a3cb7385692f"
    class InitTutorialEnd:
        UUID: Final[str] = "5a2edb29-5d2b-49af-8456-57e332a33e8f"



from typing import Final

class Ngsl:
    class Book1:
        TITLE: Final[str] = "NGSL Book 1 of 4 (New General Service List v1.01)"
        UUID: Final[str] = "b7091029-cc77-4616-990f-a21f142a5590"
    class Book2:
        TITLE: Final[str] = "NGSL Book 2 of 4 (New General Service List v1.01)"
        UUID: Final[str] = "eda14e15-86f9-4f30-b77b-a307e2a9a7e4"
    class Book3:
        TITLE: Final[str] = "NGSL Book 3 of 4 (New General Service List v1.01)"
        UUID: Final[str] = "61a33310-a0e6-4ac2-a2f2-099a864c0dc4"
    class Book4:
        TITLE: Final[str] = "NGSL Book 4 of 4 (New General Service List v1.01)"
        UUID: Final[str] = "9a8601a6-caa1-484c-8111-e890634997c0"

class NgslSpoken:
    TITLE: Final[str] = "NGSL-Spoken v1.2 (New General Service List-Spoken)"
    UUID: Final[str] = "5849035d-a37a-4dec-9498-677885e5d43f"

AllDefaultBooks = [NgslSpoken, Ngsl.Book1, Ngsl.Book2, Ngsl.Book3, Ngsl.Book4]




from enum import IntEnum

from volsite_postgres_common.api.enum.enum import create_enum_type


class LaneDecoratorType(IntEnum):
    # ====== 1100 - 1200 Cloud ======
    Cloud_01 = 1101,
    Cloud_02 = 1102,
    Cloud_03 = 1103,
    Cloud_05 = 1105,
    Cloud_07 = 1107,
    Cloud_09 = 1109,

    # ====== 2500 - 2999 Sea Monsters ======
    BabyAspidochelone = 2500,




from enum import IntEnum

class SiteStandType(IntEnum):

    DnaTile = 11,
    FocusTile = 12,
    GravelTile = 13,
    MarbleStand = 14,
    StonePlatform = 15,
    StoneStand = 16,

    # def insert_enum(conn):
    #     create_enum_type(E.SiteStandType, SiteStandType, conn)
